import React, { useState, useEffect } from "react";
import TextField from "@mui/material/TextField";
import Button from "@mui/material/Button";
import Typography from "@mui/material/Typography";
import { router, usePage } from "@inertiajs/react";

const TripDays = ({ numberOfDays }) => {
    const { package_id, flash, package_name, no_of_days } = usePage().props;
    const [openProgress, setOpenProgress] = useState(false);

    // Initialize state to track day titles and descriptions
    const [tripData, setTripData] = useState(
        Array.from({ length: no_of_days }, () => ({
            day: "",
            title: "",
            description: "",
            option1: "",
            option2: "",
            option3: "",
        }))
    );

    // Function to handle changes in day title or description
    const handleInputChange = (index, field, value) => {
        setTripData((prevState) => {
            const newData = [...prevState];
            newData[index][field] = value;
            return newData;
        });
    };

    useEffect(() => {
        setOpenProgress(false);
        if (flash && flash.success) {
            setOpenProgress(false);
            // setOpenDialog(false);
        }
    }, [flash]);
    // Function to handle form submission
    const handleSubmit = (event) => {
        event.preventDefault();
        setOpenProgress(true);
        console.log("tripData", tripData);
        // return;
        router.post(`/dashboard/edit-package-days/${package_id}`, tripData);
    };

    // Function to generate the JSX for a single day
    const renderDay = (dayNumber, index) => {
        return (
            <div className="flex single__count" key={`day-${dayNumber}`}>
                <div className="shrink-0 day__count">
                    <div className="lg:w-[52px] lg:h-[52px] w-10 h-10 rounded-full  border border-primary-1 flex justify-center items-center lg:text-lg md:2md text-md font-semibold text-primary-1 bg-white">
                        {dayNumber.toString().padStart(2, "0")}
                    </div>
                </div>
                <div className="lg:ml-[18px] w-full ml-4 pb-8">
                    <form>
                        <h5 className="lg:text-[22px] text-md font-semibold text-dark-1 !lg:mt-[10px] !mt-2">
                            Day {dayNumber.toString().padStart(2, "0")}:
                            <TextField
                                type="text"
                                label="Title"
                                value={tripData[index].title}
                                className="w-full mb-2"
                                onChange={(e) => {
                                    handleInputChange(
                                        index,
                                        "title",
                                        e.target.value
                                    );
                                    handleInputChange(index, "day", index + 1);
                                }}
                            />
                        </h5>
                        <p>
                            <TextField
                                label="Description"
                                className="w-full mb-2"
                                value={tripData[index].description}
                                rows={6}
                                multiline
                                onChange={(e) =>
                                    handleInputChange(
                                        index,
                                        "description",
                                        e.target.value
                                    )
                                }
                            />
                        </p>
                        <ul className="w-full mb-2">
                            <li>
                                <TextField
                                    type="text"
                                    label="option1"
                                    value={tripData[index].option1}
                                    size="small"
                                    onChange={(e) =>
                                        handleInputChange(
                                            index,
                                            "option1",
                                            e.target.value
                                        )
                                    }
                                />
                            </li>
                            <li>
                                <TextField
                                    type="text"
                                    size="small"
                                    value={tripData[index].option2}
                                    label="option2"
                                    onChange={(e) =>
                                        handleInputChange(
                                            index,
                                            "option2",
                                            e.target.value
                                        )
                                    }
                                />
                            </li>
                            <li>
                                <TextField
                                    type="text"
                                    label="option3"
                                    value={tripData[index].option3}
                                    size="small"
                                    onChange={(e) =>
                                        handleInputChange(
                                            index,
                                            "option3",
                                            e.target.value
                                        )
                                    }
                                />
                            </li>
                        </ul>
                    </form>
                </div>
            </div>
        );
    };

    // Generate an array of day numbers from 1 to numberOfDays
    const days = Array.from({ length: no_of_days }, (_, index) => index + 1);

    return (
        <div className="w-full">
            <Typography
                variant="h4"
                className="text-center w-ful"
                onClick={(event) => handleSubmit(event)}
            >
                {package_name}
            </Typography>
            {days.map((day, index) => renderDay(day, index))}
            <Button
                type="submit"
                variant="contained"
                className="w-1/2 m-5"
                onClick={(event) => handleSubmit(event)}
                disabled={openProgress}
            >
                Save
            </Button>
        </div>
    );
};

export default TripDays;
